Change Log for OppiaMobile Platform Components — OppiaMobile 0.7.1 documentation

# Change Log for OppiaMobile Platform Components

The OppiaMobile platform consists of 3 core components (server, client app and the Moodle export block). This page summarises the currently released versions of each of these and the changelog history for each.

## OppiaMobile Server (Django)

- OppiaMobile Server Change Log
  - v0.7.2 - not yet released
  - v0.7.1 - released 18 Feb 2015
  - v0.7.0 - released 11 Feb 2015
  - v0.6.0 - released 22 Dec 2014
  - Previous Versions

## OppiaMobile Client App (Android)

- OppiaMobile Android App Change Log
  - v51 (5.x) - not yet released
  - v50 (5.0.1) - released: 30 Dec 2014
  - v49 (5.0.0) - released beta version: 18 Nov 2014
  - v48 (4.1.2) - released: 1 Oct 2014

## OppiaMobile export block for Moodle

- OppiaMobile Moodle Block Change Log
  - vX - not yet released
  - v2015021800 - released: 18 Feb 2015
  - v2015011900 - released: 19 Jan 2015
  - v2014102900 - released: 29 Oct 2014